pub struct Options(/* private fields */);Expand description
Option struct containing flags for enabling extra features that are not part of the CommonMark spec.
Implementations
Sourceimpl Options
impl Options
pub const ENABLE_TABLES: Self
Sourcepub const ENABLE_FOOTNOTES: Self
pub const ENABLE_FOOTNOTES: Self
pub const ENABLE_STRIKETHROUGH: Self
pub const ENABLE_TASKLISTS: Self
Sourcepub const ENABLE_SMART_PUNCTUATION: Self
pub const ENABLE_SMART_PUNCTUATION: Self
Enables replacement of ASCII punctuation characters with Unicode ligatures and smart quotes.
This includes replacing -- with —, --- with —, ... with …,
"quote" with “quote”, and 'quote' with ‘quote’.
The replacement takes place during the parsing of the document.
Sourcepub const ENABLE_HEADING_ATTRIBUTES: Self
pub const ENABLE_HEADING_ATTRIBUTES: Self
Extension to allow headings to have ID and classes.
# text { #id .class1 .class2 myattr other_attr=myvalue }
is interpreted as a level 1 heading
with the content text, ID id, classes class1 and class2 and
custom attributes myattr (without value) and
other_attr with value myvalue.
Note that ID, classes, and custom attributes should be space-separated.
Sourcepub const ENABLE_YAML_STYLE_METADATA_BLOCKS: Self
pub const ENABLE_YAML_STYLE_METADATA_BLOCKS: Self
Metadata blocks in YAML style, i.e.:
- starting with a
---line - ending with a
---or...line
Sourcepub const ENABLE_PLUSES_DELIMITED_METADATA_BLOCKS: Self
pub const ENABLE_PLUSES_DELIMITED_METADATA_BLOCKS: Self
Metadata blocks delimited by:
+++line at start+++line at end
Sourcepub const ENABLE_OLD_FOOTNOTES: Self
pub const ENABLE_OLD_FOOTNOTES: Self
Older footnote syntax. This flag implies ENABLE_FOOTNOTES, changing it to use an
older syntax instead of the new, default, GitHub-compatible syntax.
New syntax is different from the old syntax regarding indentation, nesting, and footnote references with no definition:
[^1]: In new syntax, this is two footnote definitions.
[^2]: In old syntax, this is a single footnote definition with two lines.
[^3]:
In new syntax, this is a footnote with two paragraphs.
In old syntax, this is a footnote followed by a code block.
In new syntax, this undefined footnote definition renders as
literal text [^4]. In old syntax, it creates a dangling link.Sourcepub const ENABLE_MATH: Self
pub const ENABLE_MATH: Self
With this feature enabled, two events Event::InlineMath and Event::DisplayMath
are emitted that conventionally contain TeX formulas.
Sourcepub const ENABLE_GFM: Self
pub const ENABLE_GFM: Self
Misc GitHub Flavored Markdown features not supported in CommonMark. The following features are currently behind this tag:
- Blockquote tags ([!NOTE], [!TIP], [!IMPORTANT], [!WARNING], [!CAUTION]).
Sourcepub const ENABLE_DEFINITION_LIST: Self
pub const ENABLE_DEFINITION_LIST: Self
Commonmark-HS-Extensions compatible definition lists.
title 1
: definition 1
title 2
: definition 2pub const ENABLE_SUPERSCRIPT: Self
pub const ENABLE_SUBSCRIPT: Self
Sourcepub const ENABLE_WIKILINKS: Self
pub const ENABLE_WIKILINKS: Self
Obsidian-style Wikilinks.
Sourceimpl Options
impl Options
Sourcepub const fn empty() -> Self
pub const fn empty() -> Self
Get a flags value with all bits unset.
Examples found in repository?
3fn main() {
4 let markdown_input: &str = "Hello world, this is a ~~complicated~~ *very simple* example.";
5 println!("Parsing the following markdown string:\n{}", markdown_input);
6
7 // Set up options and parser. Strikethroughs are not part of the CommonMark standard
8 // and we therefore must enable it explicitly.
9 let mut options = Options::empty();
10 options.insert(Options::ENABLE_STRIKETHROUGH);
11 let parser = Parser::new_ext(markdown_input, options);
12
13 // Write to String buffer.
14 let mut html_output: String = String::with_capacity(markdown_input.len() * 3 / 2);
15 html::push_html(&mut html_output, parser);
16
17 // Check that the output is what we expected.
18 let expected_html: &str =
19 "<p>Hello world, this is a <del>complicated</del> <em>very simple</em> example.</p>\n";
20 assert_eq!(expected_html, &html_output);
21
22 // Write result to stdout.
23 println!("\nHTML output:\n{}", &html_output);
24}More examples
5fn main() {
6 let markdown_input: &str = "This is Peter on .";
7 println!("Parsing the following markdown string:\n{}", markdown_input);
8
9 // Set up parser. We can treat is as any other iterator. We replace Peter by John
10 // and image by its alt text.
11 let parser = Parser::new_ext(markdown_input, Options::empty())
12 .map(|event| match event {
13 Event::Text(text) => Event::Text(text.replace("Peter", "John").into()),
14 _ => event,
15 })
16 .filter(|event| match event {
17 Event::Start(Tag::Image { .. }) | Event::End(TagEnd::Image) => false,
18 _ => true,
19 });
20
21 // Write to anything implementing the `Write` trait. This could also be a file
22 // or network socket.
23 let stdout = std::io::stdout();
24 let mut handle = stdout.lock();
25 handle.write_all(b"\nHTML output:\n").unwrap();
26 html::write_html_io(&mut handle, parser).unwrap();
27}3fn main() {
4 let input: &str = "Hello world, check out [my website][].";
5 println!("Parsing the following markdown string:\n{}", input);
6
7 // Setup callback that sets the URL and title when it encounters
8 // a reference to our home page.
9 let callback = |broken_link: BrokenLink| {
10 if broken_link.reference.as_ref() == "my website" {
11 println!(
12 "Replacing the markdown `{}` of type {:?} with a working link",
13 &input[broken_link.span], broken_link.link_type,
14 );
15 Some(("http://example.com".into(), "my example website".into()))
16 } else {
17 None
18 }
19 };
20
21 // Create a parser with our callback function for broken links.
22 let parser = Parser::new_with_broken_link_callback(input, Options::empty(), Some(callback));
23
24 // Write to String buffer.
25 let mut html_output: String = String::with_capacity(input.len() * 3 / 2);
26 html::push_html(&mut html_output, parser);
27
28 // Check that the output is what we expected.
29 let expected_html: &str =
30 "<p>Hello world, check out <a href=\"http://example.com\" title=\"my example website\">my website</a>.</p>\n";
31 assert_eq!(expected_html, &html_output);
32
33 // Write result to stdout.
34 println!("\nHTML output:\n{}", &html_output);
35}Sourcepub const fn all() -> Self
pub const fn all() -> Self
Get a flags value with all known bits set.
Examples found in repository?
3fn main() {
4 let markdown_input = concat!(
5 "# My Heading\n",
6 "\n",
7 "My paragraph.\n",
8 "\n",
9 "* a\n",
10 "* b\n",
11 "* c\n",
12 "\n",
13 "1. d\n",
14 "2. e\n",
15 "3. f\n",
16 "\n",
17 "> my block quote\n",
18 "\n",
19 "```\n",
20 "my code block\n",
21 "```\n",
22 "\n",
23 "*emphasis*\n",
24 "**strong**\n",
25 "~~strikethrough~~\n",
26 "[My Link](http://example.com)\n",
27 "\n",
28 "\n",
29 "| a | b |\n",
30 "| - | - |\n",
31 "| c | d |\n",
32 "\n",
33 "hello[^1]\n",
34 "[^1]: my footnote\n",
35 );
36 println!(
37 "\nParsing the following markdown string:\n{}\n",
38 markdown_input
39 );
40
41 // Set up the parser. We can treat is as any other iterator.
42 // For each event, we print its details, such as the tag or string.
43 // This filter simply returns the same event without any changes;
44 // you can compare the `event-filter` example which alters the output.
45 let parser = Parser::new_ext(markdown_input, Options::all()).map(|event| {
46 match &event {
47 Event::Start(tag) => match tag {
48 Tag::HtmlBlock => println!("HtmlBlock"),
49 Tag::Heading {
50 level,
51 id,
52 classes,
53 attrs,
54 } => println!(
55 "Heading heading_level: {} fragment identifier: {:?} classes: {:?} attrs: {:?}",
56 level, id, classes, attrs
57 ),
58 Tag::Paragraph => println!("Paragraph"),
59 Tag::List(ordered_list_first_item_number) => println!(
60 "List ordered_list_first_item_number: {:?}",
61 ordered_list_first_item_number
62 ),
63 Tag::DefinitionList => println!("Definition list"),
64 Tag::DefinitionListTitle => println!("Definition title (definition list item)"),
65 Tag::DefinitionListDefinition => println!("Definition (definition list item)"),
66 Tag::Item => println!("Item (this is a list item)"),
67 Tag::Emphasis => println!("Emphasis (this is a span tag)"),
68 Tag::Superscript => println!("Superscript (this is a span tag)"),
69 Tag::Subscript => println!("Subscript (this is a span tag)"),
70 Tag::Strong => println!("Strong (this is a span tag)"),
71 Tag::Strikethrough => println!("Strikethrough (this is a span tag)"),
72 Tag::BlockQuote(kind) => println!("BlockQuote ({:?})", kind),
73 Tag::CodeBlock(code_block_kind) => {
74 println!("CodeBlock code_block_kind: {:?}", code_block_kind)
75 }
76 Tag::Link {
77 link_type,
78 dest_url,
79 title,
80 id,
81 } => println!(
82 "Link link_type: {:?} url: {} title: {} id: {}",
83 link_type, dest_url, title, id
84 ),
85 Tag::Image {
86 link_type,
87 dest_url,
88 title,
89 id,
90 } => println!(
91 "Image link_type: {:?} url: {} title: {} id: {}",
92 link_type, dest_url, title, id
93 ),
94 Tag::Table(column_text_alignment_list) => println!(
95 "Table column_text_alignment_list: {:?}",
96 column_text_alignment_list
97 ),
98 Tag::TableHead => println!("TableHead (contains TableRow tags"),
99 Tag::TableRow => println!("TableRow (contains TableCell tags)"),
100 Tag::TableCell => println!("TableCell (contains inline tags)"),
101 Tag::FootnoteDefinition(label) => println!("FootnoteDefinition label: {}", label),
102 Tag::MetadataBlock(kind) => println!("MetadataBlock: {:?}", kind),
103 },
104 _ => (),
105 };
106 event
107 });
108
109 let mut html_output = String::new();
110 pulldown_cmark::html::push_html(&mut html_output, parser);
111 println!("\nHTML output:\n{}\n", &html_output);
112}Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: Self)
pub fn insert(&mut self, other: Self)
The bitwise or (|) of the bits in self and other.
Examples found in repository?
3fn main() {
4 let markdown_input: &str = "Hello world, this is a ~~complicated~~ *very simple* example.";
5 println!("Parsing the following markdown string:\n{}", markdown_input);
6
7 // Set up options and parser. Strikethroughs are not part of the CommonMark standard
8 // and we therefore must enable it explicitly.
9 let mut options = Options::empty();
10 options.insert(Options::ENABLE_STRIKETHROUGH);
11 let parser = Parser::new_ext(markdown_input, options);
12
13 // Write to String buffer.
14 let mut html_output: String = String::with_capacity(markdown_input.len() * 3 / 2);
15 html::push_html(&mut html_output, parser);
16
17 // Check that the output is what we expected.
18 let expected_html: &str =
19 "<p>Hello world, this is a <del>complicated</del> <em>very simple</em> example.</p>\n";
20 assert_eq!(expected_html, &html_output);
21
22 // Write result to stdout.
23 println!("\nHTML output:\n{}", &html_output);
24}Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl Options
impl Options
Sourcepub const fn iter(&self) -> Iter<Options>
pub const fn iter(&self) -> Iter<Options>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Options>
pub const fn iter_names(&self) -> IterNames<Options>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.